@@ -10,8 +10,8 @@
 ##' @usage
 ##'clustatis_FreeSort(Data, NameSub=NULL, Noise_cluster=FALSE,Itermax=30,
 ##'                            Graph_dend=TRUE, Graph_bar=TRUE, printlevel=FALSE,
-##'                            gpmax=min(6, ncol(Data)-1), Testonlyoneclust=FALSE,
-##'                            alpha=0.05, nperm=50)
+##'                            gpmax=min(6, ncol(Data)-1),rhoparam=NULL,
+##'                            Testonlyoneclust=FALSE, alpha=0.05, nperm=50)
 ##'
 ##'
 ##' @param Data data frame or matrix. Corresponds to all variables that contain subjects results. Each column corresponds to a subject and gives the groups to which the products (rows) are assigned
@@ -28,7 +28,9 @@
 ##'
 ##' @param printlevel logical. Print the number of remaining levels during the hierarchical clustering algorithm? Default: FALSE
 ##'
-##' @param gpmax logical. What is maximum number of clusters to consider? Default: min(6, ncol(Data)-1)
+##' @param gpmax logical. What is maximum number of clusters to consider? Default: min(6, number of subjects -1)
+##'
+##' @param rhoparam numerical. What is the threshold for the noise cluster? Between 0 and 1, high value can imply lot of blocks set aside. If NULL, automatic threshold is computed.
 ##'
 ##' @param Testonlyoneclust logical. Test if there is more than one cluster? Default: FALSE
 ##'
@@ -93,15 +95,16 @@
 
 clustatis_FreeSort=function(Data,NameSub=NULL, Noise_cluster=FALSE,Itermax=30,
                         Graph_dend=TRUE, Graph_bar=TRUE, printlevel=FALSE,
-                        gpmax=min(6, ncol(Data)-1), Testonlyoneclust=FALSE,
-                        alpha=0.05, nperm=50)
+                        gpmax=min(6, ncol(Data)-1),rhoparam=NULL,
+                        Testonlyoneclust=FALSE, alpha=0.05, nperm=50)
 {
 
   prepro=preprocess_FreeSort(Data, NameSub = NameSub)
 
   a=clustatis(Data=prepro$new_Data,Blocks= prepro$Blocks,NameBlocks= prepro$NameBlocks,
               Noise_cluster=Noise_cluster, scale=FALSE, Itermax=Itermax,
-              Graph_dend=Graph_dend, Graph_bar=Graph_bar, printlevel=printlevel, gpmax=gpmax,
+              Graph_dend=Graph_dend, Graph_bar=Graph_bar, printlevel=printlevel,
+              gpmax=gpmax, rhoparam=rhoparam,
               Testonlyoneclust=Testonlyoneclust, alpha=alpha, nperm=nperm)
   return(a)
 }
